const locale = {
    " (area: {measure})": "(área: {medida})",
    " (length: {measure})": "(longitud: {medida})",
    "# one hash for main heading": "# una almohadilla para el encabezado principal",
    "## two hashes for second heading": "## dos almohadillas para el encabezado secundario",
    "### three hashes for third heading": "### tres almohadillas para el encabezado ternario",
    "**double star for bold**": "**dos asteriscos para negrita**",
    "*single star for italic*": "*una estrella para cursiva*",
    "--- for a horizontal rule": "--- para una regla horizontal",
    "1 day": "1 día",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una lista de números separados por comas que define el patrón de trazos. Por ejemplo: \"5, 10, 15\".",
    "About": "Acerca de",
    "Action not allowed :(": "Acción no permitida :(",
    "Activate slideshow mode": "Activar el modo presentación de diapositivas",
    "Add a layer": "Añadir una capa",
    "Add a line to the current multi": "Añadir una línea para el multi elemento actual",
    "Add a new property": "Añadir una nueva propiedad",
    "Add a polygon to the current multi": "Añadir un polígono al multi elemento actual",
    "Add image URL": "Añadir URL de la imagen",
    "Add": "Añadir",
    "Advanced actions": "Acciones avanzadas",
    "Advanced properties": "Propiedades avanzadas",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Todas las propiedades están importadas.",
    "Allow interactions": "Permitir interacciones",
    "Allow scroll wheel zoom?": "¿Permitir acercar con la rueda central del ratón?",
    "always": "siempre",
    "Animated transitions": "Transiciones animadas",
    "Are you sure you want to cancel your changes?": "¿Está seguro que quiere cancelar sus cambios?",
    "Are you sure you want to clone this map and all its datalayers?": "¿Está seguro que quiere clonar este mapa y todas sus capas de datos?",
    "Are you sure you want to delete the feature?": "¿Está seguro que quiere borrar el elemento?",
    "Are you sure you want to delete this layer?": "¿Está seguro que quiere borrar esta capa?",
    "Are you sure you want to delete this map?": "¿Está seguro que quiere borrar este mapa?",
    "Are you sure you want to delete this property on all the features?": "¿Esta seguro que quiere borrar esta propiedad en todos los elementos?",
    "Are you sure you want to restore this version?": "¿Está seguro que quiere restaurar esta versión?",
    "Attach the map to my account": "Adjuntar el mapa a mi cuenta",
    "attribution": "atribución",
    "Auto": "Automático",
    "Automatic": "Automático",
    "Autostart when map is loaded": "Autocomenzar cuando el mapa esté cargado",
    "Back to preview": "Volver a la vista previa",
    "Background overlay url": "Url de superposición de fondo",
    "Ball": "Bola",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Navegar los datos",
    "by": "por",
    "Cache proxied request": "Caché de la petición proxy",
    "Cancel edits": "Cancelar las ediciones",
    "Caption": "Subtítulo",
    "Center map on your location": "Centrar el mapa en su ubicación",
    "Change map background": "Cambiar el fondo del mapa",
    "Change tilelayers": "Cambiar la capa de teselas",
    "Change": "Cambiar",
    "Choose the data format": "Elegir el formato de datos",
    "Choropleth breakpoints": "Puntos de ruptura de la Coropleta",
    "Choropleth classes": "Clases de coropletas",
    "Choropleth color palette": "Paleta de colores Coropleta",
    "Choropleth mode": "Modo Coropleta",
    "Choropleth property value": "Valor de la propiedad Choropleta",
    "Choropleth": "Coropleto",
    "Circle": "Círculo",
    "clear": "limpiar",
    "Click last point to finish shape": "Haga clic en el último punto para terminar la figura",
    "Click to add a marker": "Haga clic para añadir un marcador",
    "Click to continue drawing": "Haga clic para continuar dibujando",
    "Click to edit": "Clic para editar",
    "Click to start drawing a line": "Haga clic para empezar a dibujar una línea",
    "Click to start drawing a polygon": "Haga clic para empezar a dibujar un polígono",
    "Clone of {name}": "Clón de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Clone": "Clonar",
    "Close": "Cerrar",
    "Clustered": "Agrupados",
    "Clustering radius": "Radio de agrupamiento",
    "collapsed": "contraído",
    "color": "color",
    "Comma separated list of numbers, including min and max values.": "Lista de números separados por comas, incluidos los valores mínimo y máximo.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Lista separada por comas de las propiedades que se utilizarán para ordenar las características. Para invertir la ordenación, anteponga un signo menos (-). Ej. miclave,-otraclave.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valores separados por coma, tabulador o punto y coma. SRS WGS84 está implícito. Solo se importan las geometrías de los puntos. La importación buscará en los encabezados de las columnas cualquier mención de «lat» y «lon» al principio del encabezado, sin distinción de mayúsculas y minúsculas. Todas las demás columnas se importan como propiedades.",
    "Congratulations, your map has been created!": "Enhorabuena, ¡su mapa ha sido creado!",
    "Continue line": "Línea continua",
    "Coordinates": "Coordenadas",
    "copy": "copiar",
    "Credits": "Créditos",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "¿Vista actual en lugar de la vista del mapa predeterminada?",
    "Custom background": "Fondo personalizado",
    "Custom overlay": "Superposición personalizada",
    "dash array": "serie de guiones",
    "Data is browsable": "Los datos son navegables",
    "Datalayers": "Capas de datos",
    "Default interaction options": "Opciones de interacción predeterminados",
    "Default properties": "Propiedades predeterminadas",
    "Default shape properties": "Propiedades de la figura predeterminada",
    "Default view": "Vista predeterminada",
    "Default zoom level": "Nivel de acercamiento predeterminado",
    "Default": "Predeterminado",
    "Default: name": "Predeterminado: nombre",
    "Define link to open in a new window on polygon click.": "Defina un enlace para abrir en un nueva ventana al hacer clic en el polígono.",
    "define": "definir",
    "Delay between two transitions when in play mode": "Retraso entre dos transiciones cuando se está en el modo de reproducción",
    "Delete layer": "Borrar capa",
    "Delete this feature": "Borrar este elemento",
    "Delete this shape": "Borrar esta figura",
    "Delete this vertex (Alt+Click)": "Borrar este vértice (Alt+Clic)",
    "Delete": "Borrar",
    "description": "descripción",
    "Direct link": "Enlace directo",
    "Directions from here": "Direcciones desde aquí",
    "Display label": "Mostrar etiqueta",
    "Display measure": "Mostrar medición",
    "display name": "mostrar nombre",
    "Display on load": "Mostrar al cargar",
    "Display the control to open OpenStreetMap editor": "Mostrar el control para abrir el editor OpenStreetMap",
    "Display the data layers control": "Mostrrar el control de la capa de datos",
    "Display the embed control": "Mostrar el control de embebido",
    "Display the fullscreen control": "Mostrar el control de pantalla completa",
    "Display the locate control": "Mostrar el control de ubicación",
    "Display the measure control": "Mostrar el control de medida",
    "Display the search control": "Mostrar el control de búsqueda",
    "Display the star map button": "Mostrar el botón del mapa de estrellas",
    "Display the tile layers control": "Mostrar el control de capas de teselas",
    "Display the zoom control": "Mostrar el control de acercamiento",
    "Do you want to display a caption bar?": "¿Quiere mostrar la barra de subtítulos?",
    "Do you want to display a minimap?": "¿Quiere mostrar un minimapa?",
    "Do you want to display a panel on load?": "¿Quiere mostrar un panel al cargar?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "¿Quiere mostrar la ventana emergente en el pie de página?",
    "Do you want to display the scale control?": "¿Quiere mostrar el control de escala?",
    "Do you want to display the «more» control?": "¿Quiere mostrar el control «más»?",
    "Download": "Descargar",
    "Drag to reorder": "Arrastrar para reordenar",
    "Draw a marker": "Dibuja un marcador",
    "Draw a polygon": "Dibuja un polígono",
    "Draw a polyline": "Dibuja una polilínea",
    "Drawing": "Dibujo",
    "Drop": "Gota",
    "Dynamic properties": "Propiedades dinámicas",
    "Dynamic": "Dinámico",
    "Edit feature's layer": "Editar la capa del elemento",
    "Edit properties in a table": "Editar propiedades en una tabla",
    "Edit the title of the map": "Editar el título del mapa",
    "Edit this feature": "Editar este elemento",
    "Edit": "Editar",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Embeber el mapa",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Vaciar",
    "Equidistant": "Equidistante",
    "Error in the overlay URL": "Error en la URL de la superposición",
    "Error in the tilelayer URL": "Error en la URL del la capa de teselas",
    "Exit Fullscreen": "Salir de la pantalla completa",
    "expanded": "expandido",
    "Extract shape to separate feature": "Extraer la figura a un elemento separado",
    "Feature identifier key": "Clave de identificación del elemento",
    "Feature properties": "Propiedades de las funciones",
    "Fetch data each time map view changes.": "Traer datos cada vez que la vista del mapa cambie.",
    "fill color": "color de relleno",
    "fill opacity": "opacidad del relleno",
    "fill": "rellenar",
    "Fit all data": "Ajustar todos los datos",
    "Format": "Formato",
    "From zoom": "Desde el acercamiento",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (sólo enlace)",
    "GeoRSS (title + image)": "GeoRSS (título + imagen)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Ir a la página de inicio",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap intensity property": "Propiedad de la intensidad del mapa de calor",
    "Heatmap radius": "Radio del mapa de calor",
    "Heatmap": "Mapa de calor",
    "height": "altura",
    "Help": "Ayuda",
    "hidden": "escondido",
    "Hide controls": "Ocultar controles",
    "Home": "Inicio",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Cuánto simplificar la polilínea en cada nivel de acercamiento (más = mejor rendimiento y aspecto más suave, menos = más preciso)",
    "icon opacity": "opacidad del icono",
    "Icon shape": "Forma de icono",
    "Icon symbol": "Símbolo del icono",
    "If false, the polygon or line will act as a part of the underlying map.": "Si está desactivado el polígono o la línea será como una parte del mapa subyacente.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe con altura personalizada (en píxeles): {{{http://iframe.url.com|altura}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe con alto y ancho (en px) personalizado: {{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Imagen con anchura personalizada (en píxeles): {{http://imagen.url.com|anchura}}",
    "Image: {{http://image.url.com}}": "Imagen: {{http://imagen.url.com}}",
    "Import data": "Importar datos",
    "Import in a new layer": "Importar en una nueva capa",
    "Imports all umap data, including layers and settings.": "Importar todos los datos umap, incluyendo capas y ajustes.",
    "Include full screen link?": "¿Incluir el enlace a pantalla completa?",
    "Inherit": "Heredar",
    "inherit": "heredar",
    "Interaction options": "Opciones de interacción",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Datos umap inválido en {filename}",
    "Invalid umap data": "Datos umap inválido",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-medias",
    "Keep current visible layers": "Guardar capas visibles actuales",
    "kilometers": "kilómetros",
    "km": "km",
    "Label direction": "Dirección de la etiqueta",
    "Label key": "Etiqueta de la clave",
    "Labels are clickable": "Las etiquetas se pueden hacer clic",
    "Latest feature": "Última novedad",
    "Latitude": "Latitud",
    "Layer properties": "Propiedades de la capa",
    "Layer": "Capa",
    "Licence": "Licencia",
    "licence": "licencia",
    "Limit bounds": "Límites",
    "Link to view the map": "Link to view the map",
    "Link to…": "Enlace a...",
    "Link with text: [[http://example.com|text of the link]]": "Enlace con texto: [[http://ejemplo.com|texto del enlace]]",
    "Long credits": "Créditos largos",
    "Longitude": "Longitud",
    "Make main shape": "Hacer la figura principal",
    "Manage layers": "Gestionar capas",
    "Manual": "Manual",
    "Map background credits": "Créditos del fondo del mapa",
    "Map has been attached to your account": "El mapa se ha adjuntado a su cuenta",
    "Map has been saved!": "¡Se ha guardado el mapa!",
    "Map has been starred": "El mapa ha sido marcado con una estrella",
    "Map has been unstarred": "El mapa se ha desprotegido",
    "Map user content has been published under licence": "El contenido del mapa del usuario se ha publicado bajo la licencia",
    "Map's editors": "Editores del mapa",
    "Map's owner": "Propietario del mapa",
    "max East": "máximo Este",
    "max North": "máximo Norte",
    "max South": "máximo Sur",
    "max West": "máximo Oeste",
    "max zoom": "acercamiento máximo",
    "Measure distances": "Medir distancias",
    "Merge lines": "Combinar líneas",
    "mi": "mi",
    "miles": "millas",
    "min zoom": "acercamiento mínimo",
    "More controls": "Más controles",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Debe ser un valor CSS válido (por ejemplo: DarkBlue o #123456)",
    "name": "nombre",
    "nautical miles": "millas náuticas",
    "never": "nunca",
    "new window": "nueva ventana",
    "next": "siguiente",
    "NM": "NM",
    "No cache": "Sin caché",
    "No licence has been set": "Ninguna licencia se ha establecida",
    "No results": "Sin resultados",
    "no": "no",
    "No.": "No.",
    "None": "Ninguno",
    "Number of desired classes (default 5)": "Número de clases deseadas (predeterminadas 5)",
    "On the bottom": "En la parte inferior",
    "On the left": "A la izquierda",
    "On the right": "A la derecha",
    "On the top": "En la parte superior",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "opacidad",
    "Opacity": "Opacidad",
    "Open current feature on load": "Abrir el elemento actual al cargar",
    "Open link in…": "Abrir enlace en...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abre la extensión de este mapa en un editor de mapas para proveer datos más precisos a OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Propiedad de intensidad opcional para el mapa de calor",
    "Optional. Same as color if not set.": "Opcional. Igual que el color si no está establecido.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Sobrescribir el radio de agrupación (predeterminado 80)",
    "Override heatmap radius (default 25)": "Sobrescribir el radio del mapa de calor (predeterminado 25)",
    "parent window": "ventana principal",
    "Paste your data here": "Pega tus datos aquí",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Asegúrese que la licencia sea compatible con el uso que le va a dar.",
    "Please choose a format": "Elija un formato",
    "Please enter the name of the property": "Introduzca el nombre de la propiedad",
    "Please enter the new name of this property": "Introduzca el nuevo nombre de esta propiedad",
    "Please save the map first": "Guarde primero el mapa",
    "Popup (large)": "Ventana emergente (grande)",
    "Popup content style": "Estilo del contenido emergente",
    "Popup content template": "Plantilla de contenido emergente",
    "Popup shape": "Forma de la ventana emergente",
    "Popup": "Ventana emergente",
    "Powered by uMap": "Desarrollado por uMap",
    "previous": "anterior",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Propiedades importadas:",
    "Provide an URL here": "Proporcione una URL aquí",
    "Proxy request": "Petición proxy",
    "Quantiles": "Cuantiles",
    "Recent": "Recent",
    "Remote data": "Datos remotos",
    "Remove shape from the multi": "Quitar la figura del multi elemento",
    "Replace layer content": "Reemplaza el contenido de la capa",
    "Restore this version": "Restaurar esta versión",
    "Save current edits": "Guardar las ediciones actuales",
    "Save map": "Guardar el mapa",
    "Save this center and zoom": "Guardar este centrado y acercamiento",
    "Save this location as new feature": "Guardar esta ubicación como nuevo elemento",
    "Save": "Guardar",
    "Saved center and zoom": "Centro y zoom guardados",
    "Search location": "Buscar ubicación",
    "Search": "Buscar",
    "Secret edit link:": "Enlace secreto de edición:",
    "See full screen": "Ver pantalla completa",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Establecer en falso para ocultar esta capa de la presentación de diapositivas, el navegador de datos, la navegación emergente...",
    "settings": "settings",
    "Shape properties": "Propiedades de la figura",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Créditos cortos",
    "Short link": "Short link",
    "Show this layer in the caption": "Mostrar esta capa en la leyenda",
    "Show/hide layer": "Mostrar/ocultar capa",
    "Side panel": "Panel lateral",
    "Simple link: [[http://example.com]]": "Enlace simple: [[http://ejemplo.com]]",
    "Simplify": "Simplificar",
    "Skipping unknown geometry.type: {type}": "Ignorando tipo de geometría desconocida: {type}",
    "Slideshow": "Presentación de diapositivas",
    "Sort key": "Orden de la clave",
    "Split line": "Linea de división",
    "Star this map": "Marcar este mapa con una estrella",
    "Start a hole here": "Iniciar un agujero aquí",
    "Start slideshow": "Iniciar presentación de diapositivas",
    "Stop editing": "Parar de editar",
    "Stop slideshow": "Parar presentación de diapositivas",
    "Street": "Street",
    "stroke": "trazo",
    "Supported scheme": "Esquema soportado",
    "Supported variables that will be dynamically replaced": "Las variables soportadas que serán reemplazadas dinámicamente",
    "Symbol": "Symbol",
    "Table": "Tabla",
    "Text color for the cluster label": "Color del texto para la etiqueta clúster",
    "Text formatting": "Formato de texto",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "El nombre de la propiedad a utilizar como etiqueta de la característica (ej.: \"nombre\"). También puede utilizar propiedades entre llaves para utilizar más de una o mezclarlas con contenido estático (p. ej.: \"&lcub;nombre&rcub; en &lcub;lugar&rcub;\").",
    "The name of the property to use as feature unique identifier.": "El nombre de la propiedad a utilizar como identificador único del elemento.",
    "The zoom and center have been modified.": "Se han modificado el zoom y el centro.",
    "TMS format": "formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Para utilizar si el servidor remoto no permite dominios cruzados (más lento)",
    "To zoom": "Para acercar/alejar",
    "Toggle edit mode (⇧+Click)": "Conmutar el modo de edición (⇧+Clic)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Transferir la figura al elemento editado",
    "Transform to lines": "Transformar a líneas",
    "Transform to polygon": "Transformar a polígono",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Tipo de capa",
    "Unable to detect format of file {filename}": "No se puede detectar el formato de archivo {filename}",
    "Untitled layer": "Capa sin título",
    "Untitled map": "Mapa sin título",
    "Update permissions and editors": "Actualizar permisos y editores",
    "Update permissions": "Actualizar permisos",
    "Update who can see and edit the map": "Actualizar quién puede ver y editar el mapa",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Utilizar límites actuales",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Utilizar marcadores de posición con propiedades del elemento entre paréntesis, ejemplo &#123;name&#125;, serán reemplazados dinámicamente por los valores correspondientes.",
    "User content credits": "Créditos del contenido del usuario",
    "User interface options": "Opciones de la interface de usuario",
    "User location": "Ubicación del usuario",
    "Verify remote URL": "Verificar URL remota",
    "Versions": "Versiones",
    "View Fullscreen": "Ver en pantalla completa",
    "View": "Vista",
    "Visibility: {status}": "Visibilidad: {estado}",
    "weight": "peso",
    "Where do we go from here?": "¿A dónde vamos a partir de aquí?",
    "Whether to display or not polygons paths.": "Si desea mostrar o no el trayecto de los polígonos.",
    "Whether to fill polygons with color.": "Si desea rellenar los polígonos con color.",
    "Who can edit \"{layer}\"": "Quién puede editar \"{layer}\"",
    "Who can edit": "Quién puede editar",
    "Who can view": "Quién puede ver",
    "width": "anchura",
    "Will be displayed in the bottom right corner of the map": "Se mostrará en la esquina inferior izquierda del mapa",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Será visible en el subtítulo del mapa",
    "yes": "si",
    "Zoom in": "Acercar",
    "Zoom level for automatic zooms": "Nivel de acercamiento para acercamientos automáticos",
    "Zoom out": "Alejar",
    "Zoom to layer extent": "Acercamiento al nivel de la capa",
    "Zoom to the next": "Acercamiento al siguiente",
    "Zoom to the previous": "Acercamiento al anterior",
    "Zoom to this feature": "Acercamiento a este elemento",
    "Zoom to this place": "Acercamiento a este lugar",
    "{area}&#8239;acres": "{área} acres",
    "{area}&#8239;ha": "{área} ha",
    "{area}&#8239;m&sup2;": "{área} m&sup2;",
    "{area}&#8239;mi&sup2;": "{área} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{área} yd&sup2;",
    "{count} errors during import: {message}": "{count} errores durante la importación: {message}",
    "{delay} seconds": "{delay} segundos",
    "{distance}&#8239;km": "{distancia} km",
    "{distance}&#8239;m": "{distancia} m",
    "{distance}&#8239;miles": "{distancia} millas",
    "{distance}&#8239;NM": "{distancia} NM",
    "{distance}&#8239;yd": "{distancia} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Propiedades avanzadas del mapa",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Import helpers:": "Import helpers:",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Symplify all geometries to points": "Symplify all geometries to points",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "My Dashboard ({username})": "My Dashboard ({username})",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel"
}
L.registerLocale("es", locale)
L.setLocale("es")
